documentationtools.Pipe
=======================

.. abjad-lineage:: abjad.tools.documentationtools.Pipe.Pipe

.. autoclass:: abjad.tools.documentationtools.Pipe.Pipe

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.documentationtools.Pipe.Pipe.arguments
      ~abjad.tools.documentationtools.Pipe.Pipe.close
      ~abjad.tools.documentationtools.Pipe.Pipe.communicate
      ~abjad.tools.documentationtools.Pipe.Pipe.executable
      ~abjad.tools.documentationtools.Pipe.Pipe.kill
      ~abjad.tools.documentationtools.Pipe.Pipe.poll
      ~abjad.tools.documentationtools.Pipe.Pipe.read
      ~abjad.tools.documentationtools.Pipe.Pipe.read_wait
      ~abjad.tools.documentationtools.Pipe.Pipe.send_signal
      ~abjad.tools.documentationtools.Pipe.Pipe.terminate
      ~abjad.tools.documentationtools.Pipe.Pipe.timeout
      ~abjad.tools.documentationtools.Pipe.Pipe.wait
      ~abjad.tools.documentationtools.Pipe.Pipe.write
      ~abjad.tools.documentationtools.Pipe.Pipe.write_line
      ~abjad.tools.documentationtools.Pipe.Pipe.__del__
      ~abjad.tools.documentationtools.Pipe.Pipe.__eq__
      ~abjad.tools.documentationtools.Pipe.Pipe.__format__
      ~abjad.tools.documentationtools.Pipe.Pipe.__ne__
      ~abjad.tools.documentationtools.Pipe.Pipe.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`subprocess.Popen <subprocess.Popen>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.documentationtools.Pipe.Pipe.arguments
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.Pipe.Pipe.executable
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.Pipe.Pipe.timeout
   :noindex:

Methods
-------

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.close
   :noindex:

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.communicate
   :noindex:

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.kill
   :noindex:

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.poll
   :noindex:

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.read
   :noindex:

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.read_wait
   :noindex:

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.send_signal
   :noindex:

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.terminate
   :noindex:

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.wait
   :noindex:

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.write
   :noindex:

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.write_line
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.__del__
   :noindex:

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.__eq__
   :noindex:

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.__format__
   :noindex:

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.__ne__
   :noindex:

.. automethod:: abjad.tools.documentationtools.Pipe.Pipe.__repr__
   :noindex:
